@@ -8,7 +8,7 @@ package Tickit::Event;
 use strict;
 use warnings;
 
-our $VERSION = '0.59';
+our $VERSION = '0.60';
 
 use Carp;
 
@@ -75,7 +75,15 @@ our @ISA = qw( Tickit::Event );
 
 =head2 type
 
-An integer giving the focus direction; C<1> for in, C<0> for out.
+This accessor has two forms of operation.
+
+The new behaviour is that it returns a dualvar giving the focus event type as
+an integer or a string event name (C<in> or C<out>). This behaviour is
+selected if the method is invoked with any true value as an argument.
+
+The legacy behaviour is that it returns a simple boolean giving the focus
+direction; C<1> for in, C<0> for out. This legacy behaviour will be removed in
+a later version.
 
 =head2 win
 
@@ -89,6 +97,7 @@ our @ISA = qw( Tickit::Event );
 
 use overload '%{}' => sub {
    my $self = shift;
+   warnings::warnif( deprecated => "HASH access to Tickit::Event::Key is deprecated" );
    return +{ map { $_ => $self->$_ } qw( type str mod ) };
 };
 
@@ -114,6 +123,7 @@ our @ISA = qw( Tickit::Event );
 
 use overload '%{}' => sub {
    my $self = shift;
+   warnings::warnif( deprecated => "HASH access to Tickit::Event::Mouse is deprecated" );
    return +{ map { $_ => $self->$_ } qw( type button line col mod ) };
 };
 
@@ -146,6 +156,7 @@ our @ISA = qw( Tickit::Event );
 
 use overload '%{}' => sub {
    my $self = shift;
+   warnings::warnif( deprecated => "HASH access to Tickit::Event::Resize is deprecated" );
    return +{ map { $_ => $self->$_ } qw( lines cols ) };
 };
 
