@@ -8,7 +8,7 @@ package Tickit::Term;
 use strict;
 use warnings;
 
-our $VERSION = '0.59';
+our $VERSION = '0.60';
 
 use Carp;
 
@@ -108,10 +108,6 @@ sub new
 
    $self->set_utf8( $params{UTF8} ) if defined $params{UTF8};
 
-   $self->set_on_resize( $params{on_resize} ) if $params{on_resize};
-   $self->set_on_key   ( $params{on_key}    ) if $params{on_key};
-   $self->set_on_mouse ( $params{on_mouse}  ) if $params{on_mouse};
-
    return $self;
 }
 
@@ -243,19 +239,12 @@ sub bind_event_with_flags
    $self->_bind_event( @_ );
 }
 
-sub set_on_resize
+sub bind_event_default
 {
-   croak "\$term->set_on_resize is deprecated; use ->bind_event";
-}
-
-sub set_on_key
-{
-   croak "\$term->set_on_key is deprecated; use ->bind_event";
-}
-
-sub set_on_mouse
-{
-   croak "\$term->set_on_mouse is deprecated; use ->bind_event";
+   my $self = shift;
+   my ( $ev, $code, $data ) = @_;
+   warnings::warnif( deprecated => "\term->bind_event_default is deprecated; use ->bind_event" );
+   $self->_bind_event( $ev, 0, $code, $data );
 }
 
 =head2 refresh_size
@@ -517,7 +506,9 @@ sub emit_key
    my $self = shift;
    my %args = @_;
 
-   $self->_emit_key( @args{qw( type str )}, $args{mod} // 0 );
+   $self->_emit_key( Tickit::Event::Key->_new(
+      $args{type}, $args{str}, $args{mod} // 0
+   ) );
 }
 
 =head2 emit_mouse
@@ -538,7 +529,9 @@ sub emit_mouse
    my $self = shift;
    my %args = @_;
 
-   $self->_emit_mouse( @args{qw( type button line col )}, $args{mod} // 0 );
+   $self->_emit_mouse( Tickit::Event::Mouse->_new(
+      $args{type}, $args{button}, $args{line}, $args{col}, $args{mod} // 0
+   ) );
 }
 
 =head1 TODO
