@@ -8,7 +8,7 @@ package Tickit::Test;
 use strict;
 use warnings;
 
-our $VERSION = '0.59';
+our $VERSION = '0.60';
 
 use Carp;
 
@@ -249,12 +249,12 @@ sub presskey
 {
    my ( $type, $str, $mod ) = @_;
 
-   $tickit->on_key( Tickit::Event::Key->_new( $type, $str, $mod || 0 ) );
+   $term->_emit_key( Tickit::Event::Key->_new( $type, $str, $mod || 0 ) );
 }
 
 =head2 pressmouse
 
-   pressmouse( $ev, $button, $line, $col, $mod )
+   pressmouse( $type, $button, $line, $col, $mod )
 
 Fire a mouse button event
 
@@ -262,9 +262,9 @@ Fire a mouse button event
 
 sub pressmouse
 {
-   my ( $ev, $button, $line, $col, $mod ) = @_;
+   my ( $type, $button, $line, $col, $mod ) = @_;
 
-   $tickit->on_mouse( Tickit::Event::Mouse->_new( $ev, $button, $line, $col, $mod || 0 ) );
+   $term->_emit_mouse( Tickit::Event::Mouse->_new( $type, $button, $line, $col, $mod || 0 ) );
 }
 
 =head1 TEST FUNCTIONS
