@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use 5.010; # //
 
-our $VERSION = '0.59';
+our $VERSION = '0.60';
 
 use Carp;
 
@@ -643,6 +643,15 @@ sub root
 Returns the L<Tickit::Term> instance of the terminal on which this window
 lives.
 
+For forward-compatibility with a C-library implementation of C<Tickit::Window>
+it is no longer guaranteed that this method will return the same Perl-level
+terminal instance that the root window was constructed with. In particular, if
+the root window in fact lives on a mock terminal created by
+L<Tickit::Test::MockTerm> this method may "forget" this fact, returning an
+object instance simply in the C<Tickit::Term> class instead. While the
+instance will still be useable as a terminal, the fact it was a mock terminal
+may get forgotten.
+
 =cut
 
 sub term
@@ -1852,10 +1861,10 @@ sub _focus_gained
 
    if( !$child ) {
       $self->{focused} = 1;
-      $self->_fire_event( focus => Tickit::Event::Focus->_new( 1, undef ) );
+      $self->_fire_event( focus => Tickit::Event::Focus->_new( in => undef ) );
    }
    elsif( $self->{focus_child_notify} ) {
-      $self->_fire_event( focus => Tickit::Event::Focus->_new( 1, $child ) );
+      $self->_fire_event( focus => Tickit::Event::Focus->_new( in => $child ) );
    }
 
    $self->{focused_child} = $child;
@@ -1868,12 +1877,12 @@ sub _focus_lost
 
    if( my $focused_child = $self->{focused_child} ) {
       $focused_child->_focus_lost;
-      $self->_fire_event( focus => Tickit::Event::Focus->_new( 0, $focused_child ) );
+      $self->_fire_event( focus => Tickit::Event::Focus->_new( out => $focused_child ) );
    }
 
    if( $self->{focused} ) {
       undef $self->{focused};
-      $self->_fire_event( focus => Tickit::Event::Focus->_new( 0, undef ) );
+      $self->_fire_event( focus => Tickit::Event::Focus->_new( out => undef ) );
    }
 }
 
