@@ -33,6 +33,7 @@ struct TickitWindow {
   } cursor;
   bool is_visible;
   bool is_focused;
+  bool is_closed;
   bool steal_input;
   bool focus_child_notify;
 
@@ -118,6 +119,8 @@ static int on_term(TickitTerm *term, TickitEventType ev, void *_info, void *user
       };
       tickit_window_expose(win, &damage);
     }
+
+    return 1;
   }
 
   if(ev & TICKIT_EV_KEY) {
@@ -127,7 +130,7 @@ static int on_term(TickitTerm *term, TickitEventType ev, void *_info, void *user
     DEBUG_LOGF("Ik", "Key event %s %s (mod=%02x)",
         evnames[info->type], info->str, info->mod);
 
-    _handle_key(win, info);
+    return _handle_key(win, info);
   }
 
   if(ev & TICKIT_EV_MOUSE) {
@@ -194,9 +197,11 @@ static int on_term(TickitTerm *term, TickitEventType ev, void *_info, void *user
 
       _handle_mouse(root->drag_source_window, &draginfo);
     }
+
+    return !!handled;
   }
 
-  return 1;
+  return 0;
 }
 
 static void init_window(TickitWindow *win, TickitWindow *parent, TickitRect rect)
@@ -213,6 +218,7 @@ static void init_window(TickitWindow *win, TickitWindow *parent, TickitRect rect
   win->cursor.visible = true;
   win->is_visible = true;
   win->is_focused = false;
+  win->is_closed = false;
   win->steal_input = false;
   win->focus_child_notify = false;
 
@@ -300,6 +306,39 @@ TickitWindow *tickit_window_root(const TickitWindow *win)
   return ROOT_AS_WINDOW(_get_root(win));
 }
 
+size_t tickit_window_children(const TickitWindow *win)
+{
+  size_t ret = 0;
+
+  for(TickitWindow *child = win->first_child; child; child = child->next)
+    ret++;
+
+  return ret;
+}
+
+size_t tickit_window_get_children(const TickitWindow *win, TickitWindow *children[], size_t n)
+{
+  size_t ret = 0;
+
+  for(TickitWindow *child = win->first_child; ret < n && child; child = child->next)
+    children[ret++] = child;
+
+  return ret;
+}
+
+TickitTerm *tickit_window_get_term(const TickitWindow *win)
+{
+  return _get_root(win)->term;
+}
+
+void tickit_window_close(TickitWindow *win)
+{
+  if(win->parent)
+    _do_hierarchy_change(TICKIT_HIERARCHY_REMOVE, win->parent, win);
+
+  win->is_closed = true;
+}
+
 void tickit_window_destroy(TickitWindow *win)
 {
   tickit_hooklist_unbind_and_destroy(win->hooks, win);
@@ -310,14 +349,14 @@ void tickit_window_destroy(TickitWindow *win)
   for(TickitWindow *child = win->first_child; child; /**/) {
     TickitWindow *next = child->next;
 
-    tickit_window_destroy(child);
+    tickit_window_unref(child);
     child = next;
   }
 
   _purge_hierarchy_changes(win);
 
-  if(win->parent)
-    _do_hierarchy_change(TICKIT_HIERARCHY_REMOVE, win->parent, win);
+  if(!win->is_closed)
+    tickit_window_close(win);
 
   /* Root cleanup */
   if(!win->parent) {
